Python API
==========
The Python API enables maximum flexibility using crema.

.. toctree::
    :maxdepth: 1
    :hidden:
    :titlesonly:

    Overview <self>
    functions.rst
    dataset.rst
    result.rst


Functions
---------
.. currentmodule:: crema
.. autosummary::
    :nosignatures:

    read_file
    calculate_tdc

Dataset
---------
.. currentmodule:: crema.dataset
.. autosummary::
    :nosignatures:

    PsmDataset

Result
---------
.. currentmodule:: crema.result
.. autosummary::
    :nosignatures:

    Result


